..
    Copyright 2017 - Swiss Data Science Center (SDSC)
    A partnership between École Polytechnique Fédérale de Lausanne (EPFL) and
    Eidgenössische Technische Hochschule Zürich (ETHZ).

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

Renku Command Line
==================

.. automodule:: renku.cli

.. _cli-init:

``renku init``
--------------

.. automodule:: renku.cli.init

.. _cli-config:

``renku config``
----------------

.. automodule:: renku.cli.config

.. _cli-datasets:

``renku datasets``
------------------

.. automodule:: renku.cli.dataset

.. _cli-run:

``renku run``
-------------

.. automodule:: renku.cli.run

.. _cli-log:

``renku log``
-------------

.. automodule:: renku.cli.log

.. _cli-status:

``renku status``
----------------

.. automodule:: renku.cli.status

.. _cli-update:

``renku update``
----------------

.. automodule:: renku.cli.update

.. _cli-rerun:

``renku rerun``
---------------

.. automodule:: renku.cli.rerun

.. _cli-workflow:

``renku workflow``
------------------

.. automodule:: renku.cli.workflow

.. _cli-show:

``renku show``
--------------

.. automodule:: renku.cli.show

.. _cli-storage:

``renku storage``
-----------------

.. automodule:: renku.cli.storage

.. _cli-image:

``renku image``
---------------

.. automodule:: renku.cli.image

``renku githooks``
------------------

.. automodule:: renku.cli.githooks
